package gemini

  1. Overview
  2. Docs

Module Market_data.SideSource

Encapsulates various concepts of side in the market dat api.

Sourcemodule Bid_ask : sig ... end

Represents a bid or ask side.

Sourcemodule Auction : sig ... end

Represents an auction style side.

Sourcetype t = [
  1. | Bid_ask.t
  2. | Auction.t
]

A most general type of side- one of `Bid, `Ask, or `Auction.

Sourceval __t_of_sexp__ : Sexplib0.Sexp.t -> t
Sourceval to_yojson : t -> Yojson.Safe.t
include Ppx_enumerate_lib.Enumerable.S with type t := t
Sourceval all : t list
include Sexplib0.Sexpable.S with type t := t
Sourceval t_of_sexp : Sexplib0.Sexp.t -> t
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t
Sourcemodule Enum_or_string : sig ... end

Wraps a string value promoting it to type Enum enum if it is parsable as such, `String string otherwise.

Sourceval dict : (string * t) list
Sourceval of_string_opt : string -> t option
Sourceval error_message : string -> string
include Csvfields.Csv.Stringable with type t := t
Sourceval to_string : t -> string
Sourceval of_string : string -> t
Sourceval is_csv_atom : bool
Sourceval rev_csv_header' : string list -> 'a -> 'b -> string list
Sourceval rev_csv_header_spec' : Csvfields.Csv.Spec.t list -> 'a -> 'b -> Csvfields.Csv.Spec.t list
Sourceval t_of_row' : 'a -> string list -> (unit -> t) * string list
Sourceval write_row_of_t' : is_first:bool -> is_last:bool -> writer:(string -> unit) -> 'a -> 'b -> t -> unit
Sourceval csv_header : string list
Sourceval csv_header_spec : Csvfields.Csv.Spec.t list
Sourceval t_of_row : string list -> t
Sourceval row_of_t : t -> string list
Sourceval csv_load : ?separator:char -> string -> t list
Sourceval csv_load_in : ?separator:char -> Core.In_channel.t -> t list
Sourceval csv_save_fn : ?separator:char -> (string -> unit) -> t list -> unit
Sourceval csv_save_out : ?separator:char -> Core.Out_channel.t -> t list -> unit
Sourceval csv_save : ?separator:char -> string -> t list -> unit